projectal.entities.note API documentation

# projectal.entities.note

View Source

    from projectal.entity import Entity

    class Note(Entity):
        """
        Implementation of the [Note](https://projectal.com/docs/latest/#tag/Note) API.
        """
        _path = 'note'
        _name = 'NOTE'

        @classmethod
        def create(cls, holder, entity):
            """Create a Note

            `holder`: `uuId` of the owner

            `entity`: The fields of the entity to be created
            """
            holder = holder['uuId'] if isinstance(holder, dict) else holder
            params = "?holder=" + holder
            return super().create(entity, params)

class Note(projectal.entity.Entity):
View Source

    class Note(Entity):
        """
        Implementation of the [Note](https://projectal.com/docs/latest/#tag/Note) API.
        """
        _path = 'note'
        _name = 'NOTE'

        @classmethod
        def create(cls, holder, entity):
            """Create a Note

            `holder`: `uuId` of the owner

            `entity`: The fields of the entity to be created
            """
            holder = holder['uuId'] if isinstance(holder, dict) else holder
            params = "?holder=" + holder
            return super().create(entity, params)

Implementation of the Note API.

@classmethod
def create(cls, holder, entity):
View Source

        @classmethod
        def create(cls, holder, entity):
            """Create a Note

            `holder`: `uuId` of the owner

            `entity`: The fields of the entity to be created
            """
            holder = holder['uuId'] if isinstance(holder, dict) else holder
            params = "?holder=" + holder
            return super().create(entity, params)

Create a Note

`holder`: `uuId` of the owner

`entity`: The fields of the entity to be created

##### Inherited Members

projectal.entity.Entity
  Entity
  get
  update
  delete
  save
  clone
  history
  list
  match
  match_startswith
  match_endswith
  search
  query
  profile_get
  profile_set
  changes
  set_readonly
builtins.dict
  setdefault
  pop
  popitem
  keys
  items
  values
  fromkeys
  clear
  copy